package com.mcwl.web.controller.resource;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.resource.domain.MallProduct;
import com.mcwl.resource.service.MallProductService;
import com.mcwl.resource.domain.vo.MallProductVo;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 商品
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.resource
 * @Filename：MallProductController
 * @Description 商品
 * @Date：2024/12/31 10:48
 */

@RestController
@RequestMapping("/MallProduct")
public class MallProductController extends BaseController {


    private final MallProductService mallProductRuleInfoService;

    public MallProductController(MallProductService mallProductService) {
        this.mallProductRuleInfoService = mallProductService;
    }


    /**
     * 查询商品列表
     */
    @GetMapping("/list")
    public TableDataInfo list(MallProduct sysJob)
    {
        startPage();
        List<MallProduct> list = mallProductRuleInfoService.selectMallProductList(sysJob);
        return getDataTable(list);
    }


    /**
     * 获取详细信息
     */
    @GetMapping(value = "/{jobId}")
    public AjaxResult getInfo(@PathVariable("jobId") Long jobId)
    {
        return success(mallProductRuleInfoService.selectMallProductById(jobId));
    }

    /**
     * 新增
     */
    @PostMapping("/add")
    public AjaxResult add(@RequestBody MallProduct mallProduct)
    {
        mallProduct.setCreateBy(getUsername());
        return toAjax(mallProductRuleInfoService.insertMallProduct(mallProduct));
    }

    /**
     * 修改
     */
    @PutMapping("/upda")
    public AjaxResult edit(@RequestBody MallProduct mallProduct)
    {
        mallProduct.setUpdateBy(getUsername());
        return toAjax(mallProductRuleInfoService.updateMallProduct(mallProduct));
    }


    /**
     * 删除
     */
    @PostMapping
    public AjaxResult remove(@RequestBody IdsParam ids)
    {
        mallProductRuleInfoService.deleteMallProductByIds(ids);
        return success();
    }

    /**
     * 查看用户发布的作品
     * @return
     */
    @PostMapping("/selectByUserId")
    public AjaxResult selectByUserId(@RequestBody MallProductVo mallProductVo){

        Page<MallProduct> mallProductList = mallProductRuleInfoService.selectByUserId(mallProductVo);
        return AjaxResult.success(mallProductList);
    }

}
